function M = DoMatrix(T,i)
%   Funktionsbeschrieb: Es wird eine Zeile von der D&H Tabelle übergeben
%   und eine TF-Matrix zurückgegeben

%   T: Ist die  D&H Tabelle mit den Parametern alpha, a, d,tau
%   i: Die zuberechnende Zeile der D&H Tabelle
%   M: TransferMatrix der jeweiligen Zeile

M=zeros(4,4);

M=[cos(T(i,4)), (-sin(T(i,4))), 0, T(i,2);
(sin(T(i,4))*cos(T(i,1))), (cos(T(i,4))*cos(T(i,1))), (-sin(T(i,1))),((-sin(T(i,1)))*T(i,3));
(sin(T(i,4))*sin(T(i,1))), (cos(T(i,4))*sin(T(i,1))), cos(T(i,1)),(cos(T(i,1))*T(i,3));
0, 0, 0 ,1];

    
        
